@@ -11,6 +11,7 @@ from rez.utils.execution import ExecutableScriptMode, _get_python_script_files
 from rez.tests.util import TestBase, TempdirMixin, per_available_shell, \
     install_dependent
 from rez.bind import hello_world
+from rez.config import config
 import unittest
 import subprocess
 import tempfile
@@ -180,20 +181,45 @@ class TestShells(TestBase, TempdirMixin):
             self.assertEqual(_stdout(p), "Hello Rez World!")
             os.remove(path)
 
-    @per_available_shell()
+    # TODO get these shells working again
+    @per_available_shell(exclude=["cmd"])
     @install_dependent()
     def test_rez_env_output(self):
-        # here we are making sure that running a command via rez-env prints
-        # exactly what we expect.
+        target_shell = config.default_shell  # overridden by test util
 
-        # Assumes that the shell has an echo command, build-in or alias
-        cmd = [os.path.join(system.rez_bin_path, "rez-env"), "--", "echo", "hey"]
-        process = subprocess.Popen(
-            cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE, universal_newlines=True
-        )
-        sh_out = process.communicate()
-        self.assertEqual(sh_out[0].strip(), "hey")
+        def _test(txt):
+            # Assumes that the shell has an echo command, built-in or alias
+            binpath = os.path.join(system.rez_bin_path, "rez-env")
+            args = [binpath, "--shell", target_shell, "--", "echo", txt]
+
+            process = subprocess.Popen(
+                args, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE, universal_newlines=True
+            )
+            sh_out = process.communicate()
+
+            # because powershell may not exit with !0 on error, depending on
+            # how it's been configured
+            #
+            if sh_out[1]:
+                raise Exception("Command %r failed:\n%s" % (txt, sh_out[1]))
+
+            self.assertEqual(sh_out[0].strip(), txt)
+
+        # please note - it's no coincidence that there are no substrings like
+        # '$you' here. These would expand to the equivalent env-var (as
+        # intended), which would be an empty string. We're not testing that
+        # here though.
+        #
+
+        _test("hey")  # simple case
+        _test("hey you")  # with a space
+        _test("<hey>")  # special characters
+        _test("!hey>$")  # more special characters
+        _test("'hey'")  # single quotes
+        _test('"hey"')  # double quotes
+        _test("hey `")  # backtick
+        _test("hey $ ?yeah> 'you'..^!")  # throw lots of stuff at it
 
     @per_available_shell()
     @install_dependent()
