@@ -354,9 +354,8 @@ class CMD(Shell):
 
     @classmethod
     def join(cls, command):
-        # TODO: This may disappear in future [1]
-        # [1] https://bugs.python.org/issue10838
-        return subprocess.list2cmdline(command)
+        inst = cls()
+        return ' '.join(inst.escape_string(x) for x in command)
 
     @classmethod
     def line_terminator(cls):
